package com.unissoft.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.unissoft.model.SysUser;
import com.unissoft.model.SysUserPO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.jwt.Jwt;
import org.springframework.security.jwt.JwtHelper;
import org.springframework.security.oauth2.provider.token.ConsumerTokenServices;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import com.unissoft.result.ResultEnum;
import com.unissoft.result.ResultView;

import java.io.UnsupportedEncodingException;
import java.security.Principal;
import java.util.Map;

@RestController
@RequestMapping("/user")
public class UserController {

    @Autowired
    private ConsumerTokenServices consumerTokenServices;

    /**
     * 根据token获取登录用户主体相关信息（用户名，token，角色。。。等）
     *
     * @return
     */
    @GetMapping("/principal")
    public Principal user(@RequestParam(required = false) String clientName) {
        System.err.println(clientName + ":调用了principal");
        SecurityContext context = SecurityContextHolder.getContext();
        Authentication authentication = context.getAuthentication();
        return authentication;
    }

    /**
     * 清除token（注销登录）
     *
     * @param token
     * @return
     */
    @GetMapping("/logout")
    public ResultView logout(@RequestParam String token) {
        boolean b = consumerTokenServices.revokeToken(token);
        if (b) {
            return ResultView.success();
        } else {
            return ResultView.error(ResultEnum.CODE_8);
        }
    }

    /**
     * 解析jwt token
     *
     * @param token
     * @return
     */
    @GetMapping("/getCurrUserInfo")
    public SysUserPO getCurrUserInfo(@RequestParam String token) throws UnsupportedEncodingException {

        Jwt decode = JwtHelper.decode(token);

        String claims = decode.getClaims();
        JSONObject jsonObject = JSON.parseObject(claims);
        Map<String, String> jsonMap = JSONObject.toJavaObject(jsonObject, Map.class);
        JSONObject user = JSON.parseObject(jsonMap.get("user_name"));
        SysUserPO sysUserPO = JSONObject.toJavaObject(user, SysUserPO.class);

        return sysUserPO;
    }
}
